"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const boa = require('@pipcook/boa');
const tf = boa.import('tensorflow');
/**
 * this is plugin used to train tfjs model with pascal voc data format for image classification problem.
 * @param data : train data
 * @param model : model loaded before
 * @param epochs : need to specify epochs
 * @param batchSize : need to specify batch size
 * @param optimizer : need to specify optimizer
 */
const ModelEvaluate = (data, model) => __awaiter(void 0, void 0, void 0, function* () {
    let batchSize = 16;
    const { testLoader } = data;
    // sample data must contain test data
    if (testLoader) {
        const count = yield testLoader.len();
        const batches = parseInt(String(count / batchSize));
        let loss = 0;
        let accuracy = 0;
        for (let i = 0; i < batches; i++) {
            const dataBatch = yield data.testLoader.nextBatch(batchSize);
            const xs = tf.stack(dataBatch.map((ele) => ele.data));
            const ys = tf.stack(dataBatch.map((ele) => ele.label));
            const evaluateRes = yield model.model.evaluate(xs, ys);
            loss += Number(evaluateRes[0].numpy());
            accuracy += Number(evaluateRes[1].numpy());
        }
        loss /= batches;
        accuracy /= batches;
        console.log(`Evaluate Result: loss: ${loss} accuracy: ${accuracy}`);
        return {
            loss,
            accuracy
        };
    }
    // just skiped if no test loader.
    return { pass: true };
});
exports.default = ModelEvaluate;
//# sourceMappingURL=index.js.map